@@ -5,7 +5,7 @@ from selenium.webdriver.common.by import By
 
 class setup_shortcuts:
     '''Shortcut functions for Selenium'''
-    def __init__(self, port=9222, wait_for=10, browser='chrome', executable_path='chromedriver', headless=False, browser_version=None, driver=None):
+    def __init__(self, browser='chrome', port=9222, wait_for=10, executable_path='chromedriver', headless=False, use_uc=False, browser_version=None, driver=None):
         self.browser_process_id = None
 
         if not driver:
@@ -14,8 +14,10 @@ class setup_shortcuts:
             except requests.exceptions.ConnectionError: # Otherwise, start Chrome
                 possible_chrome_locations = []
                 if 'darwin' in sys.platform:
-                    possible_chrome_locations.append('/Applications/Google Chrome.app/Contents/MacOS/Google Chrome')
-                    possible_chrome_locations.append('/Applications/Chromium.app/Contents/MacOS/Chromium')
+                    if browser == 'chromium':
+                        possible_chrome_locations.append('/Applications/Chromium.app/Contents/MacOS/Chromium')
+                    else:
+                        possible_chrome_locations.append('/Applications/Google Chrome.app/Contents/MacOS/Google Chrome')
                 else:
                     system_drive = os.environ.get('SYSTEMDRIVE') # 'C:\'
                     folders_chrome_could_be_installed_to = [
@@ -24,9 +26,11 @@ class setup_shortcuts:
                         os.environ.get('LOCALAPPDATA')
                         ]
                     for folder in folders_chrome_could_be_installed_to:
-                        possible_chrome_locations.append(f'{folder}/Google/Chrome/Application/chrome.exe')
-                        possible_chrome_locations.append(f'{folder}/Chromium/Application/chrome.exe')
-
+                        if browser == 'chromium':
+                            possible_chrome_locations.append(f'{folder}/Chromium/Application/chrome.exe')
+                        else:
+                            possible_chrome_locations.append(f'{folder}/Google/Chrome/Application/chrome.exe')
+                            
                 for candidate in possible_chrome_locations:
                     if os.path.exists(candidate):
                         launch_arguments = [candidate, f'--remote-debugging-port={port}', f'--user-data-dir={os.getcwd()}/profile', '--start-maximized', '--no-default-browser-check', '--no-first-run', '--credentials_enable_service=false', '--profile.password_manager_enabled=false', '--disable-save-password-bubble', '--disable-notifications']
@@ -38,7 +42,7 @@ class setup_shortcuts:
             
             options = webdriver.ChromeOptions()
             options.debugger_address = f'127.0.0.1:{port}' # Must be 127.0.0.1 for undetected-chromedriver, not localhost
-            if browser == 'uc':
+            if use_uc:
                 import undetected_chromedriver as uc
                 driver = uc.Chrome(options=options, use_subprocess=True, driver_executable_path=executable_path, version_main=browser_version)
                 os.kill(driver.browser_pid, 15) # undetected-chromedriver connects to the existing browser then starts a browser on a random port, this closes the random browser
@@ -109,16 +113,16 @@ class setup_shortcuts:
         if not check_current_url or parent.current_url != url:
             parent.get(url)
 
-    def check(self, css_selector, parent=None):
+    def check(self, css_selector, parent=None, check_visible=True):
         if not parent:
             parent = self.driver
         self.driver.implicitly_wait(1)
         elements = parent.find_elements(By.CSS_SELECTOR, css_selector)
         self.driver.implicitly_wait(self.wait_for)
-        if elements: # and elements[0].is_displayed():
-            return elements
-        else:
-            return []
+        if elements:
+            if not check_visible or elements[-1].is_displayed():
+                return elements
+        return []
     
     def close(self):
         if self.browser_process_id:
